==> vue-email-builder-0.0.1.tgz: package/README.md <==
# Yakoue Email Editor

## Install

### CDN

```html
<script src="https://unpkg.com/@yakoue/vue-email-builder"></script>
```

### NPM

```
$ npm install @yakoue/vue-email-builder --save
or
$ yarn @yakoue/vue-email-builder

```

## component

```vue
<template>
  <div id="example">
    <div class="container">
      <div id="bar">
        <h1>Vue Email Editor (Demo)</h1>

        <button @click="saveDesign">Save Design</button>
        <button @click="exportHtml">Export HTML</button>
      </div>

      <YakoueEditor ref="emailbuilder" :config="config" @init="editorLoaded" />
    </div>
  </div>
</template>

<script>
import { YakoueEditor } from '../components'
import templateData from '../data/template1.js'
export default {
  name: 'Example',
  components: {
    YakoueEditor,
  },
  data() {
    return {
      config: {},
      /* template: templateData, */
    }
  },
  mounted() {
    this.$nextTick(() => {})
  },
  methods: {
    editorLoaded() {
      // this.$refs.emailbuilder.instance.setTemplate(templateData)

      this.$refs.emailbuilder.instance.addEvent('onExport', (data) => {
        console.log('exportHtml', data)
      })
    },
    saveDesign() {
      // console.log(' template ' + JSON.stringify(templateData, null, 2))
      this.$refs.emailbuilder.instance.addEvent('onSave', (design) => {
        console.log('saveDesign', JSON.stringify(design, null, 2))
      })
      this.$refs.emailbuilder.instance.save()
    },
    exportHtml() {
      this.$refs.emailbuilder.instance.export()
    },
  },
}
</script>
```

### Compiles and hot-reloads for development

```
yarn serve
```

### Compiles and minifies for production

```
yarn build
```

### Lints and fixes files

```
yarn lint
```

### Customize configuration

See [Configuration Reference](https://cli.vuejs.org/config/).

==> vue-email-builder-0.0.2.tgz: package/README.md <==
# Yakoue Email Editor

![Yakoue Email builder](https://my-ykmail-bucket.s3.eu-west-3.amazonaws.com/icons/yakoue-vuejs1.png)

## Install

### CDN

```html
<script src="https://unpkg.com/@yakoue/vue-email-builder"></script>
```

### NPM

```
$ npm install @yakoue/vue-email-builder --save
or
$ yarn @yakoue/vue-email-builder

```

## component

```vue
<template>
  <div id="example">
    <div class="container">
      <div id="bar">
        <h1>Vue Email Editor (Demo)</h1>

        <button @click="saveDesign">Save Design</button>
        <button @click="exportHtml">Export HTML</button>
      </div>

      <YakoueEditor ref="emailbuilder" :config="config" @load="editorLoaded" />
    </div>
  </div>
</template>

<script>
import { YakoueEditor } from '../components'
import templateData from '../data/template1.js'
export default {
  name: 'Example',
  components: {
    YakoueEditor,
  },
  data() {
    return {
      config: {},
      emailTemplate: `<mjml> 
<mj-body> 
    <mj-section> 
        <mj-column> 
            <mj-text>
                <h1> Hey Title! </h1> 
            </mj-text>
                <mj-button> Hi nestor! </mj-button>
        </mj-column>
    </mj-section>  
</mj-body> 
</mjml>`,
    }
  },
  methods: {
    editorLoaded(instance) {
      //
      this.instance = instance
      this.instance.addEvent('onExport', (data) => {
        console.log('exportHtml', data)
      })
      this.instance.setTemplate(emailTemplate)
    },
    saveDesign() {
      this.addEvent('onSave', (design) => {
        console.log('saveDesign', JSON.stringify(design, null, 2))
      })
      this.instance.save()
    },
    exportHtml() {
      this.instance.export()
    },
  },
}
</script>
```

### Compiles and hot-reloads for development

```
yarn serve
```

### Compiles and minifies for production

```
yarn build
```

### Lints and fixes files

```
yarn lint
```

### Customize configuration

See [Configuration Reference](https://cli.vuejs.org/config/).
